package ui_test

import (
	"testing"
	"time"

	"github.com/kyma-project/kyma/components/console-backend-service/internal/domain/ui"
	testingUtils "github.com/kyma-project/kyma/components/console-backend-service/internal/testing"
	"github.com/kyma-project/kyma/components/console-backend-service/pkg/apis/ui/v1alpha1"
	"github.com/kyma-project/kyma/components/console-backend-service/pkg/client/clientset/versioned/fake"
	"github.com/kyma-project/kyma/components/console-backend-service/pkg/client/informers/externalversions"
	"github.com/stretchr/testify/assert"
	"github.com/stretchr/testify/require"
	v1 "k8s.io/apimachinery/pkg/apis/meta/v1"
	"k8s.io/apimachinery/pkg/runtime"
	"k8s.io/client-go/tools/cache"
)

func TestBackendModuleService_List(t *testing.T) {
	t.Run("Success", func(t *testing.T) {
		backendModule1 := fixBackendModule("1")
		backendModule2 := fixBackendModule("2")
		backendModule3 := fixBackendModule("3")

		backendModuleInformer := fixInformer(backendModule1, backendModule2, backendModule3)
		svc := ui.NewBackendModuleService(backendModuleInformer)

		testingUtils.WaitForInformerStartAtMost(t, time.Second, backendModuleInformer)

		instances, err := svc.List()
		require.NoError(t, err)
		assert.Contains(t, instances, backendModule1)
		assert.Contains(t, instances, backendModule2)
		assert.Contains(t, instances, backendModule3)
	})

	t.Run("NotFound", func(t *testing.T) {
		backendModuleInformer := fixInformer()

		svc := ui.NewBackendModuleService(backendModuleInformer)

		testingUtils.WaitForInformerStartAtMost(t, time.Second, backendModuleInformer)

		var emptyArray []*v1alpha1.BackendModule
		instances, err := svc.List()
		require.NoError(t, err)
		assert.Equal(t, emptyArray, instances)
	})
}

func fixInformer(objects ...runtime.Object) cache.SharedIndexInformer {
	client := fake.NewSimpleClientset(objects...)
	informerFactory := externalversions.NewSharedInformerFactory(client, 0)

	informer := informerFactory.Ui().V1alpha1().BackendModules().Informer()

	return informer
}

func fixBackendModule(name string) *v1alpha1.BackendModule {
	module := v1alpha1.BackendModule{
		ObjectMeta: v1.ObjectMeta{
			Name: name,
		},
	}

	return &module
}
