# Migrate from 1.20 to 1.21

## Eventing
In Kyma 1.21.0, the Eventing component has been switched completely from Knative to Kyma internal Subscription Custom Resource which is based on NATS server. 

### Troubleshooting

In case the subscribers fail to get triggered by events, check the status of the subscriptions:

```bash
## Get all subscriptions
kubectl get subscriptions.eventing.kyma-project.io -n <your-namespace>
## Check status sub-resource of the subscription resource
kubectl get subscriptions.eventing.kyma-project.io <subscription-name> -n <your-namespace> -oyaml
```

### Upgrade process

The upgrade process takes care of migrating triggers to subscriptions and changing the subscriber URL to sink (subscriber) URL if the `svc.cluster.local` suffix is missing. It can break `triggers` which have subscribers outside the namespace of the trigger (which is now called subscription) or outside the Kyma cluster. This is a known limitation of the new Subscription CRD. The sink of the subscription CR should be a Kubernetes cluster-local URL for a service which is in the same namespace as that of the subscription. The `eventType.value` for each `filter` is of the format: `prefix.application-name.event-type.version`. For example, `sap.kyma.custom.commerce.order.created.v1`. This is equivalent to a trigger with a following filter:
```
filter:
  attributes:
    eventtypeversion: v1
    source: commerce
    type: order.created
```

> In worst case scenarios, the old configurations can be found in a configmap called `eventing-post-upgrade-backed-up-data` in the Namespace `kyma-system`, where the upgrade process stores data before the upgrade.

This is an example of a trigger with its equivalent subscription:
```
---
## Trigger
apiVersion: eventing.knative.dev/v1alpha1
kind: Trigger
metadata:
  generation: 1
  labels:
    eventing.knative.dev/broker: default
  name: vibrant-hellman
  namespace: test
  ownerReferences:
  - apiVersion: serverless.kyma-project.io/v1alpha1
    kind: Function
    name: test
    uid: f982d53d-02c2-40ef-ba0b-78373b61bfe3
  selfLink: /apis/eventing.knative.dev/v1alpha1/namespaces/test/triggers/vibrant-hellman
spec:
  broker: default
  filter:
    attributes:
      eventtypeversion: v1
      source: commerce
      type: order.created
  subscriber:
    uri: http://test.test.svc.cluster.local:80/
---
## Subscription
apiVersion: eventing.kyma-project.io/v1alpha1
kind: Subscription
metadata:
  finalizers:
  - eventing.kyma-project.io
  generation: 1
  labels:
    eventing.knative.dev/broker: default
  name: vibrant-hellman
  namespace: test
  ownerReferences:
  - apiVersion: serverless.kyma-project.io/v1alpha1
    kind: Function
    name: test
    uid: f982d53d-02c2-40ef-ba0b-78373b61bfe3
  selfLink: /apis/eventing.kyma-project.io/v1alpha1/namespaces/test/subscriptions/vibrant-hellman
spec:
  filter:
    filters:
    - eventSource:
        property: source
        type: exact
        value: ""
      eventType:
        property: type
        type: exact
        value: sap.kyma.custom.commerce.order.created.v1
  protocol: ""
  protocolsettings: {}
  sink: http://test.test.svc.cluster.local:80/
```
